package cn.com.poc.thirdparty.resource.demand.ai.function;

import cn.com.poc.common.service.RedisService;
import cn.com.poc.common.utils.BlContext;
import cn.hutool.json.JSONObject;
import com.google.gson.Gson;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class SearchMemoryContentByNameFunction extends AbstractLargeModelFunction {

    @Resource
    private RedisService redisService;

    @Override
    public String doFunction(String content, String key) {
        // 用enum给定的内容名来查询用户相关信息

        // 创建 JSONObject 对象
        JSONObject jsonObject = new JSONObject(content);
        String contentName = jsonObject.getStr("content");

        StringBuffer result = new StringBuffer();
        // 先查询变量记忆
        String contentKey = key + ":" + BlContext.getCurrentUserNotException().getUserId().toString() + ":" + contentName;

        result.append(redisService.get(contentKey));
        // 如果短期记忆没查到
        return result.toString();
    }

    @Override
    public List<String> getVariableStructureLLMConfig(String[] variableStructure) {
        Map<String, Object> config = new HashMap<>();

        Map<String, Object> function = new HashMap<>();
        Map<String, Object> parameters = new HashMap<>();
        parameters.put("type", "object");

        List<String> required = new ArrayList<>();
        required.add("content");
        parameters.put("required", required);
        // 根据变量名查询记忆方法
        Map<String, Object> content = new HashMap<>();
        content.put("type", "string");
        content.put("description", "内容名");
        content.put("enum", variableStructure); // 设置变量
        Map<String, Object> searchProperties = new HashMap<>();
        searchProperties.put("content", content);
        parameters.put("properties", searchProperties);
        parameters.put("type","object");

        function.put("name", "search_memory_content_by_Enum");
        function.put("description", "用enum给定的内容名来查询用户信息（什么内容都可以）");
        function.put("parameters", parameters);

        config.put("type", "function");
        config.put("function", function);

        // 将 Map 转换为 JSON 字符串
        Gson gson = new Gson();
        String jsonString = gson.toJson(config);

        List<String> resultList = new ArrayList<>();
        resultList.add(jsonString);
        return resultList;
    }
}
